@@ -54,7 +54,7 @@ class TaskAssignator:
         if 'ts' in kwargs:
             self.ts = kwargs.get('ts', 3)
 
-    async def new_process(self, queue_tasks, * args, **kwargs):
+    async def new_process(self, queue_tasks, *args, **kwargs):
         """
         This coroutine activate a process with new station task
         Check every \ts\ seconds the queue_tasks if there are new
@@ -137,7 +137,7 @@ class TaskAssignator:
         asyncio.set_event_loop(loop)
         try:
             args = [self.queue_tasks]
-            # bprint("New process task")
+            bprint("New process task")
             task = loop.create_task(
                 coromask(
                     self.new_process,
@@ -153,6 +153,7 @@ class TaskAssignator:
                     self.new_process,
                     simple_fargs_out)
             )
+            print(f"Msg mangaer task {task}")
             if not loop.is_running():
                 loop.run_until_complete(asyncio.gather(task))
         except Exception as ex:
