@@ -40,9 +40,6 @@ def renew(task, coro, fargs, *args, **kwargs):
     :param args: the unpacked list of extra arguments
     """
     if not task.cancelled():
-        exception =task.exception()
-        if exception:
-            raise task.result()
         try:
             result = task.result()
             result_args, result_kwargs = result
@@ -50,6 +47,12 @@ def renew(task, coro, fargs, *args, **kwargs):
             task = loop.create_task(
                 coromask(coro, result_args, result_kwargs, fargs))
             task.add_done_callback(functools.partial(renew, task, coro, fargs))
+        except asyncio.InvalidStateError as ie:
+            print("Invalid State Error", ie,
+                  "Coro", coro,
+                  "args", args,
+                  "kargs", kwargs)
+            raise ie
         except Exception as e:
             print("Resultado", result, task, coro, fargs)
             print("Excepcion en renew", e)
